@echo off
setlocal EnableDelayedExpansion

echo --------------------------------------------------------
echo  DeckMania StreamDeck Blender: Install addon to Blender
echo --------------------------------------------------------
echo.

::::::::::::::::::::::::::::::: Check for administrative privileges
:: Uncomment and uncomment these lines to require admin privileges
net session >nul 2>&1
if %errorLevel% NEQ 0 (
    echo This script requires administrative privileges...
    powershell -Command "Start-Process '%~f0' -Verb RunAs"
    exit /b
)

::::::::::::::::::::::::::::::: Execute

:: Define paths
set "source=C:\Users\%USERNAME%\AppData\Roaming\Elgato\StreamDeck\Plugins\com.deckmania.blender.sdPlugin\deckmania_streamdeck_blender"
set "blenderAddonsFolder=C:\Users\%USERNAME%\AppData\Roaming\Blender Foundation\Blender"

:: Check if the folders exist
if not exist "%source%" (
    echo The folder %source% was not found. Please verify if the plugin is installed in StreamDeck.
    pause
    exit /b
)
:: Check if the Blender Addons folder exists
if not exist "%blenderAddonsFolder%" (
    echo The folder %blenderAddonsFolder% was not found. Please verify if Blender is installed.
    pause
    exit /b
)

:: Loop through directories in the Blender folder to check if the addon folder exists
for /d %%D in ("%blenderAddonsFolder%\*") do (

    set "folderName=%%~nxD"  :: Extract the folder name
    set "target=%%~fD\scripts\addons\deckmania_streamdeck_blender"
    
    :: Check if the folder name matches a valid version format (e.g., 4.0, 4.1, etc.)
    for /f "tokens=1,2 delims=." %%a in ("!folderName!") do (
        set "major=%%a"
        set "minor=%%b"
    )
    
    set "versionValid=0"
    
    :: Check if the major version is 4 or higher, and if the minor version is 3 or higher if the major version is 4
    if "!major!" NEQ "" if !major! GEQ 4 (
        if "!minor!" NEQ "" if !minor! GEQ 3 (
            set "versionValid=1"
        )
    )

    :: If the version is valid, check if the target folder exists
    if "!versionValid!"=="1" (
        :: Check if \scripts\addons\ exists, if not create it
        if not exist "%%~fD\scripts" (
            echo Creating \scripts directory in %%~fD...
            mkdir "%%~fD\scripts"
        )
        if not exist "%%~fD\scripts\addons" (
            echo Creating \addons directory in %%~fD\scripts...
            mkdir "%%~fD\scripts\addons"
        )

        :: Now proceed to create the symbolic link
        set /p userChoice="Do you want to add the add-on to Blender version !major!.!minor!? (Y/N): "
        
        if /i "!userChoice!"=="Y" (
            if exist "!target!" (
                echo The target folder already exists: !target!
                echo.
            ) else (
                echo Creating symbolic link: !target!
                mklink /D "!target!" "!source!"
                echo.
            )
        ) else (
            echo Skipping Blender version !major!.!minor!.
            echo.
        )
    ) else (
        echo Skipping unsupported Blender version !major!.!minor!.
        echo.
    )
)

pause